@@ -1,7 +1,9 @@
 from typing import List, Any
 
+from deliverable_model.batch_like_dict import BatchLikeDict
 
-class Request(dict):
+
+class Request(BatchLikeDict):
     """
     Represent a list of request object
     """
@@ -10,6 +12,14 @@ class Request(dict):
         self.query_history = []
         self["data"] = query
 
+    @classmethod
+    def from_dict(cls, data) -> "Request":
+        self = cls(None)
+        for k, v in data.items():
+            self[k] = v
+
+        return self
+
     @property
     def query(self):
         return self["data"]
